from setuptools import setup

setup(name='pychance',
      version='0.1',
      description='An unofficial implementation of the Perchance text generation engine.',
      url='https://github.com/utoxin/PyChance',
      author='Utoxin',
      author_email='utoxin@gmail.com',
      license='MIT',
      packages=['pychance'],
      zip_safe=False)
